from dataclasses import dataclass


@dataclass(frozen=True)
class MimeTypes:
	"""
	Dataclass for storing a structured list of MIME types, grouped by categories,
	including common browser MIME types for each category.

	Attributes:
		application (list[str]): Comprehensive list of MIME types of the 'application' category.
		application_common (list[str]): Commonly used 'application' MIME types in browsers.
		audio (list[str]): Comprehensive list of MIME types of the 'audio' category.
		audio_common (list[str]): Commonly used 'audio' MIME types in browsers.
		image (list[str]): Comprehensive list of MIME types of the 'image' category.
		image_common (list[str]): Commonly used 'image' MIME types in browsers.
		message (list[str]): Comprehensive list of MIME types of the 'message' category.
		message_common (list[str]): Commonly used 'message' MIME types in browsers.
		model (list[str]): Comprehensive list of MIME types of the 'model' category.
		model_common (list[str]): Commonly used 'model' MIME types in browsers.
		multipart (list[str]): Comprehensive list of MIME types of the 'multipart' category.
		multipart_common (list[str]): Commonly used 'multipart' MIME types in browsers.
		text (list[str]): Comprehensive list of MIME types of the 'text' category.
		text_common (list[str]): Commonly used 'text' MIME types in browsers.
		video (list[str]): Comprehensive list of MIME types of the 'video' category.
		video_common (list[str]): Commonly used 'video' MIME types in browsers.
		x_pkcs (list[str]): Comprehensive list of MIME types of the 'x_pkcs' category.
		x_pkcs_common (list[str]): Commonly used 'x_pkcs' MIME types in browsers.
		vnd (list[str]): Comprehensive list of MIME types of the 'vnd' category.
		vnd_common (list[str]): Commonly used 'vnd' MIME types in browsers.
	"""
	
	application = [
		"application/atom+xml",
		"application/EDI-X12",
		"application/edifact",
		"application/javascript",
		"application/json",
		"application/octet-stream",
		"application/ogg",
		"application/pdf",
		"application/postscript",
		"application/soap+xml",
		"application/xhtml+xml",
		"application/xml-dtd",
		"application/xop+xml",
		"application/zip",
		"application/gzip",
		"application/x-bittorrent",
		"application/x-tex",
		"application/xml",
		"application/msword",
		"application/vnd.ms-excel",
		"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
		"application/vnd.ms-powerpoint",
		"application/vnd.openxmlformats-officedocument.presentationml.presentation",
		"application/x-yaml",
		"application/vnd.api+json",
		"application/ld+json",
		"application/vnd.mozilla.xul+xml",
		"application/x-www-form-urlencoded",
		"application/dvi",
		"application/x-latex",
		"application/x-font-ttf",
		"application/x-shockwave-flash",
		"application/x-stuffit",
		"application/x-tar",
		"application/ecmascript",
		"application/EDI-consent",
		"application/json-patch+json",
		"application/ld+json",
		"application/manifest+json",
		"application/mathml+xml",
		"application/oebps-package+xml",
		"application/pdf",
		"application/pkcs7-mime",
		"application/pkcs7-signature",
		"application/postscript",
		"application/rdf+xml",
		"application/reginfo+xml",
		"application/relax-ng-compact+xml",
		"application/resource-lists+xml",
		"application/rfc+xml",
		"application/rls-services+xml",
		"application/rpki-manifest",
		"application/rtf",
		"application/sbml+xml",
		"application/scvp-cv-request",
		"application/scvp-cv-response",
		"application/scvp-vp-request",
		"application/scvp-vp-response",
		"application/sdp",
		"application/set-payment-initiation",
		"application/set-registration-initiation",
		"application/shf+xml",
		"application/smil+xml",
		"application/sparql-query",
		"application/sparql-results+xml",
		"application/sql",
		"application/srgs",
		"application/srgs+xml",
		"application/ssml+xml",
		"application/timestamped-data",
		"application/vnd.adobe.air-application-installer-package+zip",
		"application/vnd.adobe.flash.movie",
		"application/vnd.android.package-archive",
		"application/vnd.apple.installer+xml",
		"application/vnd.apple.keynote",
		"application/vnd.apple.numbers",
		"application/vnd.apple.pages",
		"application/vnd.bmi",
		"application/vnd.coreldraw",
		"application/vnd.dart",
		"application/vnd.debian.binary-package",
		"application/vnd.docker.image.manifest+json",
		"application/vnd.google-apps.document",
		"application/vnd.google-apps.presentation",
		"application/vnd.google-apps.spreadsheet",
		"application/vnd.hp-HPGL",
		"application/vnd.lotus-1-2-3",
		"application/vnd.mozilla.xul+xml",
		"application/vnd.ms-excel",
		"application/vnd.ms-excel.addin.macroEnabled.12",
		"application/vnd.ms-excel.sheet.binary.macroEnabled.12",
		"application/vnd.ms-excel.sheet.macroEnabled.12",
		"application/vnd.ms-fontobject",
		"application/vnd.ms-htmlhelp",
		"application/vnd.ms-officetheme",
		"application/vnd.ms-outlook",
		"application/vnd.ms-powerpoint",
		"application/vnd.ms-powerpoint.addin.macroEnabled.12",
		"application/vnd.ms-powerpoint.presentation.macroEnabled.12",
		"application/vnd.ms-powerpoint.slide.macroEnabled.12",
		"application/vnd.ms-powerpoint.slideshow.macroEnabled.12",
		"application/vnd.ms-powerpoint.template.macroEnabled.12",
		"application/vnd.ms-project",
		"application/vnd.oasis.opendocument.chart",
		"application/vnd.oasis.opendocument.chart-template",
		"application/vnd.oasis.opendocument.database",
		"application/vnd.oasis.opendocument.formula",
		"application/vnd.oasis.opendocument.formula-template",
		"application/vnd.oasis.opendocument.graphics",
		"application/vnd.oasis.opendocument.graphics-template",
		"application/vnd.oasis.opendocument.image",
		"application/vnd.oasis.opendocument.image-template",
		"application/vnd.oasis.opendocument.presentation",
		"application/vnd.oasis.opendocument.presentation-template",
		"application/vnd.oasis.opendocument.spreadsheet",
		"application/vnd.oasis.opendocument.spreadsheet-template",
		"application/vnd.oasis.opendocument.text",
		"application/vnd.oasis.opendocument.text-master",
		"application/vnd.oasis.opendocument.text-template",
		"application/vnd.oasis.opendocument.text-web",
		"application/vnd.openxmlformats-officedocument.presentationml.presentation",
		"application/vnd.openxmlformats-officedocument.presentationml.slide",
		"application/vnd.openxmlformats-officedocument.presentationml.slideshow",
		"application/vnd.openxmlformats-officedocument.presentationml.template",
		"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
		"application/vnd.openxmlformats-officedocument.spreadsheetml.template",
		"application/vnd.openxmlformats-officedocument.wordprocessingml.document",
		"application/vnd.openxmlformats-officedocument.wordprocessingml.template",
		"application/vnd.rar",
		"application/vnd.realmedia",
		"application/vnd.smaf",
		"application/vnd.syncml+xml",
		"application/vnd.tcpdump.pcap",
		"application/vnd.visio",
		"application/vnd.wordperfect",
		"application/vnd.wap.wbxml",
		"application/vnd.wap.wmlc",
		"application/vnd.xara",
		"application/voicexml+xml",
		"application/x-7z-compressed",
		"application/x-abiword",
		"application/x-bzip",
		"application/x-bzip2",
		"application/x-cdf",
		"application/x-csh",
		"application/x-debian-package",
		"application/x-dtbook+xml",
		"application/x-dvi",
		"application/x-freearc",
		"application/x-gtar",
		"application/x-gzip",
		"application/x-httpd-php",
		"application/x-iso9660-image",
		"application/x-java-archive",
		"application/x-javascript",
		"application/x-lzh-compressed",
		"application/x-mpegURL",
		"application/x-msdownload",
		"application/x-msmediaview",
		"application/x-msoffice",
		"application/x-perl",
		"application/x-php",
		"application/x-pkcs12",
		"application/x-pkcs7-certificates",
		"application/x-pkcs7-certreqresp",
		"application/x-rar-compressed",
		"application/x-redhat-package-manager",
		"application/x-ruby",
		"application/x-sh",
		"application/x-shar",
		"application/x-shockwave-flash",
		"application/x-sql",
		"application/x-stuffit",
		"application/x-sv4crc",
		"application/x-sv4pca",
		"application/x-tcl",
		"application/x-tex",
		"application/x-texinfo",
		"application/x-troff",
		"application/x-troff-man",
		"application/x-troff-me",
		"application/x-troff-ms",
		"application/x-ustar",
		"application/x-wais-source",
		"application/x-x509-ca-cert",
		"application/xml",
		"application/xml-dtd",
		"application/x-www-form-urlencoded",
		"application/zstd",
	]
	application_common = [
		"application/json",
		"application/javascript",
		"application/xml",
		"application/xhtml+xml",
		"application/pdf",
	]
	
	audio = [
		"audio/aac",
		"audio/midi",
		"audio/mpeg",
		"audio/ogg",
		"audio/opus",
		"audio/vorbis",
		"audio/vnd.dlna.adts",
		"audio/vnd.dts",
		"audio/vnd.dts.hd",
		"audio/vnd.lucent.voice",
		"audio/vnd.rn-realaudio",
		"audio/vnd.wave",
		"audio/webm",
		"audio/x-aac",
		"audio/x-aiff",
		"audio/x-flac",
		"audio/x-m4a",
		"audio/x-matroska",
		"audio/x-ms-wax",
		"audio/x-pn-realaudio",
		"audio/x-wav",
		"audio/amr",
		"audio/3gpp",
		"audio/3gpp2",
	]
	audio_common = ["audio/mpeg", "audio/ogg", "audio/webm", "audio/wav", "audio/aac",]
	
	image = [
		"image/bmp",
		"image/gif",
		"image/jpeg",
		"image/png",
		"image/svg+xml",
		"image/tiff",
		"image/vnd.microsoft.icon",
		"image/webp",
		"image/avif",
		"image/apng",
		"image/x-icon",
		"image/heif",
		"image/heic",
		"image/jp2",
		"image/jpm",
		"image/jpx",
		"image/ktx",
		"image/sgi",
	]
	image_common = [
		"image/jpeg",
		"image/png",
		"image/gif",
		"image/webp",
		"image/svg+xml",
		"image/bmp",
	]
	
	message = [
		"message/disposition-notification",
		"message/global",
		"message/global-delivery-status",
		"message/global-disposition-notification",
		"message/global-headers",
		"message/rfc822",
	]
	message_common = ["message/rfc822", "message/disposition-notification",]
	
	model = [
		"model/3dmf",
		"model/iges",
		"model/mesh",
		"model/vrml",
		"model/x3d+binary",
		"model/x3d+vrml",
		"model/x3d+xml",
		"model/gltf+json",
		"model/gltf-binary",
		"model/stl",
		"model/vnd.collada.dae+xml",
		"model/vnd.dwf",
		"model/vnd.gdl",
		"model/vnd.gs-gdl",
		"model/vnd.gtw",
		"model/vnd.moml+xml",
		"model/vnd.mts",
		"model/vnd.opengex",
		"model/vnd.parasolid.transmit.binary",
		"model/vnd.parasolid.transmit.text",
		"model/vnd.rosette.convrml.restrict+xml",
		"model/vnd.rosette.diskdata",
		"model/vnd.vtu",
		"model/x-3ds",
		"model/x-cgm",
		"model/x-gdl",
		"model/x-iges",
		"model/x-obj",
		"model/x-stl-ascii",
		"model/x-stl-binary",
		"model/x-vrml",
		"model/x-x3d",
	]
	model_common = [
		"model/gltf+json",
		"model/gltf-binary",
		"model/obj",
		"model/stl",
		"model/vrml",
		"model/x3d+xml",
	]
	
	multipart = [
		"multipart/alternative",
		"multipart/appledouble",
		"multipart/digest",
		"multipart/encrypted",
		"multipart/form-data",
		"multipart/mixed",
		"multipart/parallel",
		"multipart/related",
		"multipart/report",
		"multipart/signed",
		"multipart/byteranges",
		"multipart/alternative",
		"multipart/form-data",
		"multipart/related",
	]
	multipart_common = [
		"multipart/form-data",
		"multipart/mixed",
		"multipart/related",
		"multipart/alternative",
	]
	
	text = [
		"text/css",
		"text/csv",
		"text/html",
		"text/javascript",
		"text/plain",
		"text/rtf",
		"text/sgml",
		"text/tab-separated-values",
		"text/vcard",
		"text/xml",
		"text/vtt",
		"text/cache-manifest",
		"text/calendar",
		"text/coffeescript",
		"text/csv-schema",
		"text/directory",
		"text/dns",
		"text/ecmascript",
		"text/enriched",
		"text/example",
		"text/fenced-code-block",
		"text/flowed",
		"text/grammar-ref-list",
		"text/hdml",
		"text/idl",
		"text/inkml",
		"text/javascript",
		"text/jcr-cnd",
		"text/markdown",
		"text/mizar",
		"text/n3",
		"text/parameters",
		"text/parityfec",
		"text/plain",
		"text/prs.fallenstein.rst",
		"text/prs.lines.tag",
		"text/provenance-notation",
		"text/raptorfec",
		"text/red",
		"text/rfc822-headers",
		"text/richtext",
		"text/rtf",
		"text/rtx",
		"text/sgml",
		"text/shex",
		"text/slim",
		"text/spdx",
		"text/spreadsheet",
		"text/strings",
		"text/stylus",
		"text/t140",
		"text/tab-separated-values",
		"text/troff",
		"text/turtle",
		"text/uri-list",
		"text/vcard",
		"text/vnd.curl.dcurl",
		"text/vnd.curl.mcurl",
		"text/vnd.curl.scurl",
		"text/vnd.dvb.subtitle",
		"text/vnd.fly",
		"text/vnd.fmi.flexstor",
		"text/vnd.graphviz",
		"text/vnd.in3d.3dml",
		"text/vnd.in3d.spot",
		"text/vnd.latex-z",
		"text/vnd.motorola.flex.afp",
		"text/vnd.ms-mediapackage",
		"text/vnd.net2phone.dtmf",
		"text/vnd.rn-realtext",
		"text/vnd.sun.j2me.app-descriptor",
		"text/vnd.wap.si",
		"text/vnd.wap.sl",
		"text/vnd.wap.wml",
		"text/vnd.wap.wmls",
		"text/vtt",
		"text/x-asm",
		"text/x-c",
		"text/x-component",
		"text/x-fortran",
		"text/x-gwt-rpc",
		"text/x-handlebars-template",
		"text/x-java-source",
		"text/x-lua",
		"text/x-markdown",
		"text/x-nfo",
		"text/x-opml",
		"text/x-pascal",
		"text/x-processing",
		"text/x-python",
		"text/x-sass",
		"text/x-scss",
		"text/x-setext",
		"text/x-sfv",
		"text/x-sh",
		"text/x-tcl",
		"text/x-tex",
		"text/x-vcalendar",
		"text/x-vcard",
		"text/xml",
	]
	text_common = [
		"text/html",
		"text/plain",
		"text/css",
		"text/javascript",
		"text/xml",
		"text/csv",
		"text/vtt",
	]
	
	video = [
		"video/mpeg",
		"video/mp4",
		"video/ogg",
		"video/quicktime",
		"video/webm",
		"video/x-msvideo",
		"video/x-matroska",
		"video/3gpp",
		"video/3gpp2",
		"video/h261",
		"video/h263",
		"video/h264",
		"video/h265",
		"video/jpeg",
		"video/jpm",
		"video/jpx",
		"video/mj2",
		"video/mp2t",
		"video/mpv",
		"video/mpeg",
		"video/mpeg4",
		"video/ogg",
		"video/quicktime",
		"video/vnd.mpegurl",
		"video/vnd.mpegurl",
		"video/vnd.vivo",
		"video/webm",
		"video/x-f4v",
		"video/x-fli",
		"video/x-flv",
		"video/x-m4v",
		"video/x-mjpeg",
		"video/x-matroska",
		"video/x-mpeg",
		"video/x-mpeg2",
		"video/x-mpegurl",
		"video/x-ms-asf",
		"video/x-ms-wmv",
		"video/x-ms-wmx",
		"video/x-ms-wvx",
		"video/x-mvi",
		"video/x-sgi-movie",
		"video/x-smv",
	]
	video_common = ["video/mp4", "video/webm", "video/ogg", "video/mpeg",]
	
	x_pkcs = [
		"application/x-pkcs12",
		"application/x-pkcs7-certificates",
		"application/x-pkcs7-certreqresp",
	]
	x_pkcs_common = ["application/x-pkcs12", "application/x-pkcs7-certificates",]
	
	vnd = [
		"application/vnd.adobe.air-application-installer-package+zip",
		"application/vnd.adobe.flash.movie",
		"application/vnd.android.package-archive",
		"application/vnd.apple.installer+xml",
		"application/vnd.apple.keynote",
		"application/vnd.apple.numbers",
		"application/vnd.apple.pages",
		"application/vnd.bmi",
		"application/vnd.coreldraw",
		"application/vnd.dart",
		"application/vnd.debian.binary-package",
		"application/vnd.docker.image.manifest+json",
		"application/vnd.google-apps.document",
		"application/vnd.google-apps.presentation",
		"application/vnd.google-apps.spreadsheet",
		"application/vnd.hp-HPGL",
		"application/vnd.lotus-1-2-3",
		"application/vnd.mozilla.xul+xml",
		"application/vnd.ms-excel",
		"application/vnd.ms-excel.addin.macroEnabled.12",
		"application/vnd.ms-excel.sheet.binary.macroEnabled.12",
		"application/vnd.ms-excel.sheet.macroEnabled.12",
		"application/vnd.ms-fontobject",
		"application/vnd.ms-htmlhelp",
		"application/vnd.ms-officetheme",
		"application/vnd.ms-outlook",
		"application/vnd.ms-powerpoint",
		"application/vnd.ms-powerpoint.addin.macroEnabled.12",
		"application/vnd.ms-powerpoint.presentation.macroEnabled.12",
		"application/vnd.ms-powerpoint.slide.macroEnabled.12",
		"application/vnd.ms-powerpoint.slideshow.macroEnabled.12",
		"application/vnd.ms-powerpoint.template.macroEnabled.12",
		"application/vnd.ms-project",
		"application/vnd.oasis.opendocument.chart",
		"application/vnd.oasis.opendocument.chart-template",
		"application/vnd.oasis.opendocument.database",
		"application/vnd.oasis.opendocument.formula",
		"application/vnd.oasis.opendocument.formula-template",
		"application/vnd.oasis.opendocument.graphics",
		"application/vnd.oasis.opendocument.graphics-template",
		"application/vnd.oasis.opendocument.image",
		"application/vnd.oasis.opendocument.image-template",
		"application/vnd.oasis.opendocument.presentation",
		"application/vnd.oasis.opendocument.presentation-template",
		"application/vnd.oasis.opendocument.spreadsheet",
		"application/vnd.oasis.opendocument.spreadsheet-template",
		"application/vnd.oasis.opendocument.text",
		"application/vnd.oasis.opendocument.text-master",
		"application/vnd.oasis.opendocument.text-template",
		"application/vnd.oasis.opendocument.text-web",
		"application/vnd.openxmlformats-officedocument.presentationml.presentation",
		"application/vnd.openxmlformats-officedocument.presentationml.slide",
		"application/vnd.openxmlformats-officedocument.presentationml.slideshow",
		"application/vnd.openxmlformats-officedocument.presentationml.template",
		"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
		"application/vnd.openxmlformats-officedocument.spreadsheetml.template",
		"application/vnd.openxmlformats-officedocument.wordprocessingml.document",
		"application/vnd.openxmlformats-officedocument.wordprocessingml.template",
		"application/vnd.rar",
		"application/vnd.realmedia",
		"application/vnd.smaf",
		"application/vnd.syncml+xml",
		"application/vnd.tcpdump.pcap",
		"application/vnd.visio",
		"application/vnd.wordperfect",
		"application/vnd.wap.wbxml",
		"application/vnd.wap.wmlc",
		"application/vnd.xara",
		"audio/vnd.dlna.adts",
		"audio/vnd.dts",
		"audio/vnd.dts.hd",
		"audio/vnd.lucent.voice",
		"audio/vnd.rn-realaudio",
		"audio/vnd.wave",
		"text/vnd.curl.dcurl",
		"text/vnd.curl.mcurl",
		"text/vnd.curl.scurl",
		"text/vnd.dvb.subtitle",
		"text/vnd.fly",
		"text/vnd.fmi.flexstor",
		"text/vnd.graphviz",
		"text/vnd.in3d.3dml",
		"text/vnd.in3d.spot",
		"text/vnd.latex-z",
		"text/vnd.motorola.flex.afp",
		"text/vnd.ms-mediapackage",
		"text/vnd.net2phone.dtmf",
		"text/vnd.rn-realtext",
		"text/vnd.sun.j2me.app-descriptor",
		"text/vnd.wap.si",
		"text/vnd.wap.sl",
		"text/vnd.wap.wml",
		"text/vnd.wap.wmls",
		"video/vnd.mpegurl",
		"video/vnd.mpegurl",
		"video/vnd.vivo",
	]
	vnd_common = [
		"application/vnd.ms-excel",
		"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
		"application/vnd.ms-powerpoint",
		"application/vnd.openxmlformats-officedocument.presentationml.presentation",
		"application/vnd.openxmlformats-officedocument.wordprocessingml.document",
		"application/vnd.mozilla.xul+xml",
		"application/vnd.api+json",
	]
